# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_app_request_one_of_configuration import CreateAppRequestOneOfConfiguration  # noqa: E501
from onelogin.rest import ApiException

class TestCreateAppRequestOneOfConfiguration(unittest.TestCase):
    """CreateAppRequestOneOfConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateAppRequestOneOfConfiguration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAppRequestOneOfConfiguration`
        """
        model = onelogin.models.create_app_request_one_of_configuration.CreateAppRequestOneOfConfiguration()  # noqa: E501
        if include_optional :
            return CreateAppRequestOneOfConfiguration(
                login_url = '', 
                redirect_uri = '', 
                access_token_expiration_minutes = 56, 
                refresh_token_expiration_minutes = 56, 
                token_endpoint_auth_method = 56, 
                oidc_application_type = 56
            )
        else :
            return CreateAppRequestOneOfConfiguration(
                login_url = '',
                redirect_uri = '',
                access_token_expiration_minutes = 56,
                refresh_token_expiration_minutes = 56,
                token_endpoint_auth_method = 56,
                oidc_application_type = 56,
        )
        """

    def testCreateAppRequestOneOfConfiguration(self):
        """Test CreateAppRequestOneOfConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
