# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_client_apps200_response import ListClientApps200Response  # noqa: E501
from onelogin.rest import ApiException

class TestListClientApps200Response(unittest.TestCase):
    """ListClientApps200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListClientApps200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListClientApps200Response`
        """
        model = onelogin.models.list_client_apps200_response.ListClientApps200Response()  # noqa: E501
        if include_optional :
            return ListClientApps200Response(
                scopes = [
                    onelogin.models.list_client_apps_200_response_scopes_inner.listClientApps_200_response_scopes_inner(
                        id = 25, 
                        value = 'read:contacts', 
                        description = 'Read some contacts', )
                    ], 
                app_id = 1026152, 
                name = 'An oidc app', 
                api_auth_id = 1033034
            )
        else :
            return ListClientApps200Response(
        )
        """

    def testListClientApps200Response(self):
        """Test ListClientApps200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
