# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_brand201_response_logo import CreateBrand201ResponseLogo  # noqa: E501
from onelogin.rest import ApiException

class TestCreateBrand201ResponseLogo(unittest.TestCase):
    """CreateBrand201ResponseLogo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateBrand201ResponseLogo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateBrand201ResponseLogo`
        """
        model = onelogin.models.create_brand201_response_logo.CreateBrand201ResponseLogo()  # noqa: E501
        if include_optional :
            return CreateBrand201ResponseLogo(
                urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                    original = '', 
                    login = '', 
                    navigation = '', ), 
                file_size = 56, 
                updated_at = '', 
                content_type = ''
            )
        else :
            return CreateBrand201ResponseLogo(
                urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                    original = '', 
                    login = '', 
                    navigation = '', ),
                file_size = 56,
                updated_at = '',
                content_type = '',
        )
        """

    def testCreateBrand201ResponseLogo(self):
        """Test CreateBrand201ResponseLogo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
