# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_app_request_one_of1 import CreateAppRequestOneOf1  # noqa: E501
from onelogin.rest import ApiException

class TestCreateAppRequestOneOf1(unittest.TestCase):
    """CreateAppRequestOneOf1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateAppRequestOneOf1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAppRequestOneOf1`
        """
        model = onelogin.models.create_app_request_one_of1.CreateAppRequestOneOf1()  # noqa: E501
        if include_optional :
            return CreateAppRequestOneOf1(
                connector_id = 56, 
                name = '', 
                description = '', 
                visible = True, 
                policy_id = 56, 
                configuration = onelogin.models.create_app_request_one_of_1_configuration.createApp_request_oneOf_1_configuration(
                    signature_algorithm = '', 
                    certificate_id = 56, ), 
                parameters = onelogin.models.create_app_request_one_of_1_parameters.createApp_request_oneOf_1_parameters(
                    saml_username = onelogin.models.create_app_request_one_of_1_parameters_saml_username.createApp_request_oneOf_1_parameters_saml_username(
                        user_attribute_mappings = '', ), )
            )
        else :
            return CreateAppRequestOneOf1(
                connector_id = 56,
                name = '',
                description = '',
                visible = True,
                policy_id = 56,
                configuration = onelogin.models.create_app_request_one_of_1_configuration.createApp_request_oneOf_1_configuration(
                    signature_algorithm = '', 
                    certificate_id = 56, ),
                parameters = onelogin.models.create_app_request_one_of_1_parameters.createApp_request_oneOf_1_parameters(
                    saml_username = onelogin.models.create_app_request_one_of_1_parameters_saml_username.createApp_request_oneOf_1_parameters_saml_username(
                        user_attribute_mappings = '', ), ),
        )
        """

    def testCreateAppRequestOneOf1(self):
        """Test CreateAppRequestOneOf1"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
