# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_authclaims200_response_inner import GetAuthclaims200ResponseInner  # noqa: E501
from onelogin.rest import ApiException

class TestGetAuthclaims200ResponseInner(unittest.TestCase):
    """GetAuthclaims200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetAuthclaims200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetAuthclaims200ResponseInner`
        """
        model = onelogin.models.get_authclaims200_response_inner.GetAuthclaims200ResponseInner()  # noqa: E501
        if include_optional :
            return GetAuthclaims200ResponseInner(
                id = 320780, 
                label = 'email_address', 
                user_attribute_mappings = 'email', 
                user_attribute_macros = '', 
                attribute_transformations = '', 
                skip_if_blank = True, 
                values = [], 
                default_values = '', 
                provisioned_entitlements = True
            )
        else :
            return GetAuthclaims200ResponseInner(
        )
        """

    def testGetAuthclaims200ResponseInner(self):
        """Test GetAuthclaims200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
