# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.ver_factor_saml_request import VerFactorSamlRequest  # noqa: E501
from onelogin.rest import ApiException

class TestVerFactorSamlRequest(unittest.TestCase):
    """VerFactorSamlRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VerFactorSamlRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VerFactorSamlRequest`
        """
        model = onelogin.models.ver_factor_saml_request.VerFactorSamlRequest()  # noqa: E501
        if include_optional :
            return VerFactorSamlRequest(
                app_id = '1657651', 
                device_id = '1657651', 
                state_token = '11x0x1x16x1x3259xxxx0x59xx6xxxx670x61x45xxxxx', 
                otp_token = '999999', 
                do_not_notify = False
            )
        else :
            return VerFactorSamlRequest(
                app_id = '1657651',
                device_id = '1657651',
                state_token = '11x0x1x16x1x3259xxxx0x59xx6xxxx670x61x45xxxxx',
        )
        """

    def testVerFactorSamlRequest(self):
        """Test VerFactorSamlRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
