# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_brand201_response import CreateBrand201Response  # noqa: E501
from onelogin.rest import ApiException

class TestCreateBrand201Response(unittest.TestCase):
    """CreateBrand201Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateBrand201Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateBrand201Response`
        """
        model = onelogin.models.create_brand201_response.CreateBrand201Response()  # noqa: E501
        if include_optional :
            return CreateBrand201Response(
                id = 56, 
                enabled = True, 
                custom_support_enabled = False, 
                custom_color = '#1298b4', 
                custom_accent_color = '#b60012', 
                custom_masking_color = '#beefed', 
                custom_masking_opacity = 40, 
                mfa_enrollment_message = 'You must register with the OneLogin Protect app in order to login', 
                enable_custom_label_for_login_screen = True, 
                custom_label_text_for_login_screen = 'ACME Username or Email', 
                login_instruction = 'To login, enter your ACME Username or Email. Reach out to help.desk@acme.org if you have trouble logging in.', 
                login_instruction_title = 'ACME Login Instructions', 
                hide_onelogin_footer = True, 
                background = onelogin.models.create_brand_201_response_background.createBrand_201_response_background(
                    urls = onelogin.models.create_brand_201_response_background_urls.createBrand_201_response_background_urls(
                        original = '', 
                        login = '', 
                        branding = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ), 
                logo = onelogin.models.create_brand_201_response_logo.createBrand_201_response_logo(
                    urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                        original = '', 
                        login = '', 
                        navigation = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', )
            )
        else :
            return CreateBrand201Response(
                id = 56,
                enabled = True,
                custom_support_enabled = False,
                custom_color = '#1298b4',
                custom_accent_color = '#b60012',
                custom_masking_color = '#beefed',
                custom_masking_opacity = 40,
                mfa_enrollment_message = 'You must register with the OneLogin Protect app in order to login',
                enable_custom_label_for_login_screen = True,
                custom_label_text_for_login_screen = 'ACME Username or Email',
                login_instruction = 'To login, enter your ACME Username or Email. Reach out to help.desk@acme.org if you have trouble logging in.',
                login_instruction_title = 'ACME Login Instructions',
                hide_onelogin_footer = True,
                background = onelogin.models.create_brand_201_response_background.createBrand_201_response_background(
                    urls = onelogin.models.create_brand_201_response_background_urls.createBrand_201_response_background_urls(
                        original = '', 
                        login = '', 
                        branding = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ),
                logo = onelogin.models.create_brand_201_response_logo.createBrand_201_response_logo(
                    urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                        original = '', 
                        login = '', 
                        navigation = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ),
        )
        """

    def testCreateBrand201Response(self):
        """Test CreateBrand201Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
