# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_apps200_response import ListApps200Response  # noqa: E501
from onelogin.rest import ApiException

class TestListApps200Response(unittest.TestCase):
    """ListApps200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListApps200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListApps200Response`
        """
        model = onelogin.models.list_apps200_response.ListApps200Response()  # noqa: E501
        if include_optional :
            return ListApps200Response(
                id = 1061937, 
                connector_id = 50534, 
                name = 'Amazon Web Services Multi-Role', 
                description = 'Whatever you  like', 
                notes = '', 
                policy_id = 56, 
                brand_id = 56, 
                icon_url = '', 
                visible = True, 
                auth_method = 2, 
                tab_id = 56, 
                created_at = '2020-01-14T21:21:06.000Z', 
                updated_at = '2020-01-14T21:21:06.000Z', 
                role_ids = [
                    56
                    ], 
                allow_assumed_signin = True, 
                provisioning = onelogin.models.list_apps_200_response_provisioning.listApps_200_response_provisioning(
                    enabled = True, )
            )
        else :
            return ListApps200Response(
        )
        """

    def testListApps200Response(self):
        """Test ListApps200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
